# jai - A Lego-style Deep Learning Library Build on PyTorch

## Dev. Plan
1. Refactor the augmentation pipeline
2. Clean up the code in arch
3. Implement the check failure case method. Use open cv + keyboard control